import { 
  ApiResponse, 
  Certificate, 
  CreateCertificateData, 
  DownloadCertificateParams,
  PaginatedResponse 
} from '../../types'
import { apiClient } from './client'

export const certificatesApi = {
  getAll: async (page = 1, perPage = 50): Promise<ApiResponse<PaginatedResponse<Certificate>>> => {
    const response = await apiClient.get('/certificates', {
      params: { page, per_page: perPage }
    })
    return response.data
  },

  create: async (data: CreateCertificateData): Promise<ApiResponse<Certificate>> => {
    const response = await apiClient.post('/certificates', data)
    return response.data
  },

  revoke: async (certificateId: number): Promise<ApiResponse> => {
    const response = await apiClient.post(`/certificates/${certificateId}/revoke`)
    return response.data
  },

  download: async (params: DownloadCertificateParams): Promise<Blob> => {
    const response = await apiClient.get('/certificates/download', {
      params,
      responseType: 'blob',
    })
    return response.data
  },

  getStats: async (): Promise<ApiResponse<{ 
    total: number
    active: number 
    revoked: number 
    expiring_soon: Certificate[] 
  }>> => {
    const response = await apiClient.get('/certificates/stats')
    return response.data
  },
}